@@ -460,15 +460,6 @@ brasero_libisofs_import_last_session (BraseroLibisofs *self,
 	if (!priv->ctx)
 		return BRASERO_BURN_ERR;
 
-	src = g_new0 (IsoDataSource, 1);
-	src->version = 0;
-	src->refcount = 1;
-	src->read_block = brasero_libisofs_import_read;
-	src->open = brasero_libisofs_import_open;
-	src->close = brasero_libisofs_import_close;
-	src->free_data = brasero_libisofs_import_free;
-	src->data = priv->ctx->drive;
-
 	result = iso_read_opts_new (&opts, 0);
 	if (result < 0) {
 		g_set_error (error,
@@ -478,6 +469,15 @@ brasero_libisofs_import_last_session (BraseroLibisofs *self,
 		return BRASERO_BURN_ERR;
 	}
 
+	src = g_new0 (IsoDataSource, 1);
+	src->version = 0;
+	src->refcount = 1;
+	src->read_block = brasero_libisofs_import_read;
+	src->open = brasero_libisofs_import_open;
+	src->close = brasero_libisofs_import_close;
+	src->free_data = brasero_libisofs_import_free;
+	src->data = priv->ctx->drive;
+
 	brasero_job_get_last_session_address (BRASERO_JOB (self), &session_block);
 	iso_read_opts_set_start_block (opts, session_block);
 
@@ -604,7 +604,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 	grafts = g_slist_sort (grafts, brasero_libisofs_sort_graft_points);
 
 	/* add global exclusions */
-	for (excluded = brasero_track_data_get_excluded (BRASERO_TRACK_DATA (track), FALSE);
+	for (excluded = brasero_track_data_get_excluded_list (BRASERO_TRACK_DATA (track));
 	     excluded; excluded = excluded->next) {
 		gchar *uri, *local;
 
@@ -1034,17 +1034,17 @@ brasero_libisofs_finalize (GObject *object)
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-static BraseroBurnResult
-brasero_libisofs_export_caps (BraseroPlugin *plugin, gchar **error)
+static void
+brasero_libisofs_export_caps (BraseroPlugin *plugin)
 {
 	GSList *output;
 	GSList *input;
 
 	brasero_plugin_define (plugin,
 			       "libisofs",
-			       _("libisofs creates disc images from files"),
+			       _("Creates disc images from a file selection"),
 			       "Philippe Rouquier",
-			       0);
+			       3);
 
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_CDR|
@@ -1091,6 +1091,4 @@ brasero_libisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 	g_slist_free (output);
 
 	brasero_plugin_register_group (plugin, _(LIBBURNIA_DESCRIPTION));
-
-	return BRASERO_BURN_OK;
 }
