@@ -29,27 +29,12 @@
 #include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
 
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkcomboboxentry.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkcellrenderer.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcelllayout.h>
+#include <gtk/gtk.h>
 
 #include <gconf/gconf-client.h>
 
-#include "burn-plugin.h"
-#include "burn-plugin-private.h"
+#include "brasero-plugin.h"
+#include "brasero-plugin-information.h"
 #include "brasero-plugin-option.h"
 
 enum {
@@ -101,7 +86,7 @@ brasero_plugin_option_save_settings (BraseroPluginOption *self)
 		gchar *key;
 
 		widget = iter->data;
-		if (!GTK_WIDGET_IS_SENSITIVE (widget->widget))
+		if (!gtk_widget_is_sensitive (widget->widget))
 			continue;
 
 		brasero_plugin_conf_option_get_info (widget->option,
@@ -405,7 +390,8 @@ brasero_plugin_option_set_plugin (BraseroPluginOption *self,
 
 	priv = BRASERO_PLUGIN_OPTION_PRIVATE (self);
 
-	tmp = g_strdup_printf (_("Options for plugin %s"), brasero_plugin_get_name (plugin));
+	/* Use the translated name for the plugin. */
+	tmp = g_strdup_printf (_("Options for plugin %s"), _(brasero_plugin_get_name (plugin)));
 	string = g_strdup_printf ("<b>%s</b>", tmp);
 	g_free (tmp);
 
@@ -440,7 +426,7 @@ brasero_plugin_option_init (BraseroPluginOption *object)
 	gtk_container_set_border_width (GTK_CONTAINER (priv->vbox), 8);
 	gtk_container_add (GTK_CONTAINER (frame), priv->vbox);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (object)->vbox),
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (object))),
 			    frame,
 			    FALSE,
 			    FALSE,
